Pysh
====
Every day we stray further from God's light.

What is this?
-------------
Pysh is a shell-script like language. Like shell scripts it is good for controling the flow of the execution of programs.

This repo contains the implementation of pysh in python.


Why would you do this?
----------------------



Dew is a package manager for C/C++ dependencies. It aims to make dependency management and configuration easier, like
what Cargo does for Rust. For each dependency listed in a 'dewfile', Dew downloads the source of the dependency, builds
it, and installs it's files in a prefix directory that can be used by your project.

Is it done?
-----------
No

Is it stable? Can I use this in production?
-------------------------------------------
Go away





After running dew, glfw will be installed in the ``.dew/install`` prefix directory located in the root of your project
containing the dewfile. You can pass this prefix path into your buildsystem to use all of the installed dependencies.

Better documentation for dewfiles will surface in the future.
